@@ -19,6 +19,7 @@ class SupervisorForm(BootstrapMixin, forms.ModelForm):
             'phone',
             'status',
             'comments',
+            'is_active',
         ]
 
 
@@ -29,6 +30,7 @@ class SupervisorFilterForm(BootstrapMixin, forms.ModelForm):
     )
     status = forms.ChoiceField(
         choices=BLANK_CHOICE + VirtualCircuitStatusChoices.CHOICES,
+        label="Статус",
         required=False
     )
 
@@ -48,5 +50,5 @@ class SupervisorTenantForm(BootstrapMixin, forms.ModelForm):
         model = SupervisorTenant
         fields = [
             'supervisor',
-            'tenant`',
+            'tenant',
         ]
