@@ -11,9 +11,8 @@ class SupervisorCount(PluginTemplateExtension):
     def right_page(self):
         # Map Supervisor' IDs to Tenants' IDs.
         m = {}
-
         # Filter Tenants by tenant.
-        tenants = Tenant.objects.filter(tenant=self.context['object'])
+        tenants = Tenant.objects.filter(name=self.context['object'])
         for t in tenants:
             # If a Tenant is presented, map back to its Supervisor to prevent duplicates.
             if SupervisorTenant.objects.filter(tenant=t).count() == 1:
